@@ -3,6 +3,7 @@ from django.urls import reverse
 from django.conf import settings
 from django.shortcuts import redirect, render
 from django.views.decorators.clickjacking import xframe_options_exempt
+from django.utils.decorators import method_decorator
 
 from rest_framework.views import APIView
 
@@ -20,8 +21,8 @@ class InitTokenRequestView(View):
 
     redirect_path_name = ''
 
-    @xframe_options_exempt
-    @shopify_embed
+    @method_decorator(xframe_options_exempt)
+    @method_decorator(shopify_embed)
     def get(self, request, *args, **kwargs):
 
         shopify.Session.setup(
